<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fi">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Taita</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Lisää</translation>
    </message>
</context>
<context>
    <name>NotifyCenter</name>
    <message>
        <source>No recent notifications</source>
        <translation>Ei viimeaikaisia ilmoituksia</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Ilmoituskeskus</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Tyhjennä kaikki</translation>
    </message>
    <message>
        <source>Fold</source>
        <translation>Taita</translation>
    </message>
    <message>
        <source>More</source>
        <translation>Lisää</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Irrota</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Kiinnitä</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Ilmoitusten asetukset</translation>
    </message>
</context>
<context>
    <name>NotifyViewDelegate</name>
    <message>
        <source>Clean All</source>
        <translation type="unfinished">Puhdista kaikki</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Juuri nyt</translation>
    </message>
</context>
</TS>
